<html>
    <body>
        List of imported plugins

        <ul>
            {% for plugin_name in plugin_names %}
                <li>{{ plugin_name }}</li>
            {% endfor %}
        </ul>

    </body>
</html>
