
body
{
    background-color: #F3F3F3;
    display: flex;
    align-items: center;
    flex-direction: column;
}

h1
{
    color: #424242;
    font-family:Verdana, Geneva, Tahoma, sans-serif;
}

.io_card
{
    display: flex;
    align-items: center;
    justify-content: center;

    align-self: center;

    max-width: 500px;
    padding: 20px;
}

